@@ -513,7 +513,7 @@ checkNEWS <- function(pkgdir)
     }, error=function(e){
         handleWarning(
             "news(package='", basename(pkgdir), "') failed with news file: ",
-            newsPath, ".",
+            newsPath, ":", e$message,
             "\nRefer to https://contributions.bioconductor.org/news.html",
             " to be included in Bioconductor release announcements."
         )
@@ -578,8 +578,6 @@ checkSkipOnBioc <- function(pkgdir)
 .rmYAMLfm <- function(lines) {
     fm_idx <- grep("^---\\s*$", lines)
     offval <- 0L
-    if (length(fm_idx) && !identical(length(fm_idx), 2L))
-        warning("More than 2 YAML front matter delimiters, i.e., '---' found")
     if (length(fm_idx)) {
         offval <- max(fm_idx)
         lines <- lines[-seq(min(fm_idx), offval)]
